use crate::components::Ender;
use crate::Route;
use dioxus::prelude::*;

/// The Navbar component that will be rendered on all pages of our app since every page is under the layout.
///
///
/// This layout component wraps the UI of [Route::Home] and [Route::Blog] in a common navbar. The contents of the Home and Blog
/// routes will be rendered under the outlet inside this component
#[component]
pub fn Navbar() -> Element {
    rsx! {
        document::Stylesheet { href: asset!("/assets/styling/navbar.css") }
        document::Stylesheet { href: asset!("assets/styling/standardColoursandFonts.css") }

        div { id: "navbar",
            Link { to: Route::Home {}, "Home" }
            Link { to: Route::Projects {}, "Projects" }
            Link { to: Route::Blogs { page_num: 0 }, "Blogs" }
            Link { to: Route::ContactMe {}, "Contact" }
        }

        // The `Outlet` component is used to render the next component inside the layout. In this case, it will render either
        // the [`Home`] or [`Blog`] component depending on the current route.
        Outlet::<Route> {}

        Ender {}
    }
}
